"""
Models for the custom_css app
"""

# Alliance Auth Framework
from allianceauth.framework.models import SingletonModel

# Django
from django.db import models
from django.utils.translation import gettext_lazy as _


class CustomCSS(SingletonModel):
    """
    Model for storing custom CSS for the site
    """

    css = models.TextField(
        blank=True,
        null=True,
        verbose_name=_("Your custom CSS"),
        help_text=_("This CSS will be added to the site after the default CSS."),
    )

    class Meta:
        """
        Meta for CustomCSS
        """

        default_permissions = ()
        verbose_name = _("Custom CSS")
        verbose_name_plural = _("Custom CSS")

    def __str__(self) -> str:
        return str(_("Custom CSS"))
